@@ -16,10 +16,3 @@ class Email(object):
     def __init__(self):
         self.label = None
         self.email = None
-
-class RemoteClass(object):
-    pass
-
-class ExternClass(object):
-    pass
-
